package com.sooka.sponest.monitor.aideviceevent.service.impl;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.uuid.IdUtils;
import com.sooka.sponest.monitor.aideviceevent.domain.CenterdataTAideviceevent;
import com.sooka.sponest.monitor.aideviceevent.mapper.CenterdataTAideviceeventMapper;
import com.sooka.sponest.monitor.aideviceevent.service.ICenterdataTAideviceeventService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * AI对应事件Service业务层处理
 *
 * @author yy
 * @date 2022-09-01
 */
@Service
public class CenterdataTAideviceeventServiceImpl implements ICenterdataTAideviceeventService
{
    @Autowired
    private CenterdataTAideviceeventMapper centerdataTAideviceeventMapper;

    /**
     * 查询AI对应事件
     *
     * @param id AI对应事件主键
     * @return AI对应事件
     */
    @Override
    public CenterdataTAideviceevent selectCenterdataTAideviceeventById(String id)
    {
        return centerdataTAideviceeventMapper.selectCenterdataTAideviceeventById(id);
    }

    /**
     * 查询AI对应事件列表
     *
     * @param centerdataTAideviceevent AI对应事件
     * @return AI对应事件
     */
    @Override
    public List<CenterdataTAideviceevent> selectCenterdataTAideviceeventList(CenterdataTAideviceevent centerdataTAideviceevent)
    {
        return centerdataTAideviceeventMapper.selectCenterdataTAideviceeventList(centerdataTAideviceevent);
    }

    /**
     * 新增AI对应事件
     *
     * @param centerdataTAideviceevent AI对应事件
     * @return 结果
     */
    @Override
    public int insertCenterdataTAideviceevent(CenterdataTAideviceevent centerdataTAideviceevent)
    {
        centerdataTAideviceevent.setId(IdUtils.simpleUUID());
        centerdataTAideviceevent.setCreateTime(DateUtils.getNowDate());
        return centerdataTAideviceeventMapper.insertCenterdataTAideviceevent(centerdataTAideviceevent);
    }

    /**
     * 修改AI对应事件
     *
     * @param centerdataTAideviceevent AI对应事件
     * @return 结果
     */
    @Override
    public int updateCenterdataTAideviceevent(CenterdataTAideviceevent centerdataTAideviceevent)
    {
        centerdataTAideviceevent.setUpdateTime(DateUtils.getNowDate());
        return centerdataTAideviceeventMapper.updateCenterdataTAideviceevent(centerdataTAideviceevent);
    }

    /**
     * 批量删除AI对应事件
     *
     * @param ids 需要删除的AI对应事件主键
     * @return 结果
     */
    @Override
    public int deleteCenterdataTAideviceeventByIds(String[] ids)
    {
        return centerdataTAideviceeventMapper.deleteCenterdataTAideviceeventByIds(ids);
    }

    /**
     * 删除AI对应事件信息
     *
     * @param id AI对应事件主键
     * @return 结果
     */
    @Override
    public int deleteCenterdataTAideviceeventById(String id)
    {
        return centerdataTAideviceeventMapper.deleteCenterdataTAideviceeventById(id);
    }

    //根据设备code查询
    @Override
    public List<CenterdataTAideviceevent> selectEventTypeByDeviceCode(String deviceCode)
    {
        return centerdataTAideviceeventMapper.selectEventTypeByDeviceCode(deviceCode);
    }
}
